@@ -11,7 +11,7 @@ See `CircuitPython:board` in CircuitPython for more details.
 """
 
 
-__version__ = "8.9.0"
+__version__ = "8.16.0"
 __repo__ = "https://github.com/adafruit/Adafruit_Blinka.git"
 __blinka__ = True
 
@@ -127,6 +127,9 @@ elif board_id == ap_board.ORANGE_PI_4:
 elif board_id == ap_board.ORANGE_PI_4_LTS:
     from adafruit_blinka.board.orangepi.orangepi4 import *
 
+elif board_id == ap_board.ORANGE_PI_5:
+    from adafruit_blinka.board.orangepi.orangepi5 import *
+
 elif board_id == ap_board.BANANA_PI_M2_ZERO:
     from adafruit_blinka.board.bananapi.bpim2zero import *
 
@@ -226,6 +229,9 @@ elif board_id == ap_board.ONION_OMEGA2:
 elif board_id == ap_board.RADXA_CM3:
     from adafruit_blinka.board.radxa.radxacm3 import *
 
+elif board_id == ap_board.ROCK_PI_3A:
+    from adafruit_blinka.board.radxa.rockpi3a import *
+
 elif board_id == ap_board.RADXA_ZERO:
     from adafruit_blinka.board.radxa.radxazero import *
 
@@ -235,14 +241,20 @@ elif board_id == ap_board.ROCK_PI_S:
 elif board_id == ap_board.ROCK_PI_4:
     from adafruit_blinka.board.radxa.rockpi4 import *
 
+elif board_id == ap_board.ROCK_PI_4_C_PLUS:
+    from adafruit_blinka.board.radxa.rockpi4cplus import *
+
+elif board_id == ap_board.ROCK_PI_5:
+    from adafruit_blinka.board.radxa.rock5 import *
+
 elif board_id == ap_board.ROCK_PI_E:
     from adafruit_blinka.board.radxa.rockpie import *
 
 elif board_id == ap_board.UDOO_X86:
     from adafruit_blinka.board.udoo_x86ultra import *
 
-elif board_id == ap_board.ODYSSEY_X86J4105:
-    from adafruit_blinka.board.x86j4105 import *
+elif board_id == ap_board.ODYSSEY_X86J41X5:
+    from adafruit_blinka.board.x86j41x5 import *
 
 elif board_id == ap_board.STM32MP157C_DK2:
     from adafruit_blinka.board.stm32.stm32mp157c_dk2 import *
@@ -259,6 +271,15 @@ elif board_id == ap_board.LUBANCAT_IMX6ULL:
 elif board_id == ap_board.LUBANCAT_STM32MP157:
     from adafruit_blinka.board.lubancat.lubancat_stm32mp157 import *
 
+elif board_id == ap_board.LUBANCAT_ZERO:
+    from adafruit_blinka.board.lubancat.lubancat_zero import *
+
+elif board_id == ap_board.LUBANCAT1:
+    from adafruit_blinka.board.lubancat.lubancat1 import *
+
+elif board_id == ap_board.LUBANCAT2:
+    from adafruit_blinka.board.lubancat.lubancat2 import *
+
 elif board_id == ap_board.NANOPI_NEO_AIR:
     from adafruit_blinka.board.nanopi.neoair import *
 
@@ -292,9 +313,18 @@ elif board_id == ap_board.LICHEE_RV:
 elif board_id == ap_board.SIEMENS_SIMATIC_IOT2050_ADV:
     from adafruit_blinka.board.siemens.siemens_iot2050 import *
 
+elif board_id == ap_board.SIEMENS_SIMATIC_IOT2050_BASIC:
+    from adafruit_blinka.board.siemens.siemens_iot2050 import *
+
 elif board_id == ap_board.AML_S905X_CC:
     from adafruit_blinka.board.librecomputer.aml_s905x_cc_v1 import *
 
+elif board_id == ap_board.ROC_RK3328_CC:
+    from adafruit_blinka.board.librecomputer.roc_rk3328_cc import *
+
+elif board_id == ap_board.GENERIC_LINUX_PC:
+    from adafruit_blinka.board.generic_linux_pc import *
+
 elif "sphinx" in sys.modules:
     pass
 
